#
# spec file for package stacktile
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

Name:           stacktile
Version:        1.0.0+git26
Release:        1.1
Summary:        A layour generator for the river Wayland compositor
License:        GPL-3.0-only
URL:            https://git.sr.ht/~uncomfy/stacktile
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  pkgconfig
BuildRequires:  scdoc >= 1.9.2
BuildRequires:  zig >= 0.13.0
BuildRequires:  zig-rpm-macros
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wayland-server) >= 1.20.0
BuildRequires:  zstd
Recommends:     river

%description
stacktile is a layout generator for the river Wayland compositor.

It divides the screen into three areas, the primary area, the secondary area and
the remainder area. The primary and secondary areas are populated by a
configurable amount of windows from the top of the window stack. All remaining
windows will be placed in the remainder area. The windows in these areas are
arranged into a configurable sublayout.

stacktile's layout configuration is individual per tag set. If the
layout values are changed, the change only applies to the currently
focused tag set.

%prep
%autosetup -p1 -a1

# Disable the getVersion function that uses git.
sed -i 's|try getVersion(b)|"%{version}"|g' build.zig

%build
%{zig_build} -Dpie --global-cache-dir vendor/

%install
%{zig_install} -Dpie --global-cache-dir vendor/

%check
%{zig_test}  -Dpie --global-cache-dir vendor/

%files
%license LICENSE
%doc README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sat Oct 26 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Remove wlroots as dependency
* Sat Oct 26 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Temporarily change sources to https://git.sr.ht/~uncomfy/stacktile until
  my patches are merged.
- Update to version 1.0.0+git26:
  * chore: update codebase to zig 0.13.0
  * misc: add ./.zig-cache/ to ./.gitignore
  * remove git submodules
  * allow cycling through integers in layout commands
  * add {linear, orthogonal}-center metalayouts
  * add 'display-name' option
  * Remove "per-tags" option, add "runtime-changes"
  * improve code for getting layout config override
  * Refactor columns and rows into an iterator
  * Remove outdated note from manpage
- Add vendored deps as ./vendor.tar.zst
- Remove zig-wayland.tar.gz
- Remove following patches
  * 0001-update-transition-to-be-compatible-with-zig-0.11.0.patch
  * 0002-build-add-strip-and-pie-options.patch
* Sat Jan 27 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add 0002-build-add-strip-and-pie-options.patch
* Sat Jan 27 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add zig-wayland.tar.gz
- Fix build by adding 0001-update-transition-to-be-compatible-with-zig-0.11.0.patch.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Mon Aug  7 2023 socvirnyl.estela@gmail.com
- Update to version 1.0.0+git22:
  * add {linear, orthogonal}-center metalayouts
  * add 'display-name' option
  * Remove "per-tags" option, add "runtime-changes"
  * improve code for getting layout config override
  * Refactor columns and rows into an iterator
* Fri Mar 17 2023 socvirnyl.estela@gmail.com
- Update to version 1.0.0+git17:
  * Remove outdated note from manpage
  * Add tag rule for layouts
  * Revert "add jitter; update to zig 0.10.0"
* Sat Jan 21 2023 socvirnyl.estela@gmail.com
- Update to version 1.0.0+git14:
  * add jitter; update to zig 0.10.0
- Remove set_version_manually.patch
* Wed Dec 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.0.0+git13:
  * manpage: fix minor mistakes
  * Add man page
  * set initial capacity for ArrayLists
  * document some things
- Update specfile to use zig 0.9
* Thu Aug 25 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- add set_version_manually.patch
* Thu Aug 25 2022 socvirnyl.estela@gmail.com
- Changed package to build using Zig 😄
- remove Makefile.patch
- Update to version 1.0.0+git9:
  * fix bug causing no padding to apply when only a single view is visible
  * per-tag layout config overrides
  * layout config refactor
  * update .gitignore
  * Update river-layout protocol
  * add resize-main command
  * remove outdated info from README
  * [WIP] 2.0
  * Makefile: Run $CC properly
  * Explicitly bind wl_output version
* Sat Feb 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec template
